#
# spec file for package flatpak-builder
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flatpak-builder
Version:        1.0.9
Release:        lp152.1.3
Summary:        Tool to build flatpaks from source
License:        LGPL-2.1-or-later
Group:          Development/Tools/Building
URL:            http://flatpak.org/
Source0:        https://github.com/flatpak/flatpak-builder/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gettext
BuildRequires:  gtk-doc
BuildRequires:  libcap-devel
BuildRequires:  libdwarf-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(flatpak) >= 0.11.8
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(ostree-1) >= 2018.7
BuildRequires:  pkgconfig(yaml-0.1)
Requires:       %{_bindir}/bzip2
Recommends:     %{_bindir}/bzr
Requires:       %{_bindir}/eu-strip
Requires:       %{_bindir}/git
Requires:       %{_bindir}/patch
Requires:       %{_bindir}/strip
Requires:       %{_bindir}/tar
Requires:       %{_bindir}/unzip

%description
Tool to build flatpaks from source.
See https://wiki.gnome.org/Projects/SandboxedApps for more information.

%prep
%autosetup

%build
%configure \
	--enable-docbook-docs \
	--with-dwarf-header=%{_includedir}/libdwarf \
	%{nil}
%make_build

%install
%make_install

%files
%license COPYING
%doc NEWS README.md
%doc %{_datadir}/doc/%{name}/
%{_bindir}/flatpak-builder
%{_mandir}/man1/flatpak-builder.1%{ext_man}
%{_mandir}/man5/flatpak-manifest.5%{ext_man}

%changelog
* Mon Oct 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.9:
  + More detailed commandline output with --verbose enabled.
  + Support for including yaml module snippets.
  + Support the CCACHE_DIR environment variable.
  + New option disable-submodules for git sources.
  + New commandline option --show-manifest.
  + Multiple modules with the same name in the same manifest is now
    supported.
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.8:
  + Support multiple instances of --install-dep-from.
  + Ensure shallow git mirrors are updated when the git ref
    changes.
  + Improved error reporting.
* Wed May 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.7:
  + Use the new die-with-parent feature of HostCommand when build
    to run in a flatpak.
  + Fix some details in how we create platform commits to fix font
    cache mtime issues.
- Changes from version 1.0.6:
  + Pass --noninteractive when installing for flatpak >= 1.2.0.
  + Doc fixes.
- Changes from version 1.0.5:
  + Due to a change in the output of "flatpak info" the support for
    loading default build options from the sdk regressed with
    flatpak 1.2.x. This is fixed and everyone who built flatpaks
    with 1.2.x are recommended to update to this release and
    re-build.
- Changes from version 1.0.4:
  + Add --add/remove-tag options
  + Allow using a full ref as sdk and use the branch from that.
* Wed Feb 13 2019 Thomas Bechtold <tbechtold@suse.com>
- Switch from Requires to Recommends for bzr. bzr only works for
  python2 and on a python3 only system, bzr is not available
  (bsc#1082696)
* Mon Jan 28 2019 bjorn.lie@gmail.com
- Update to version 1.0.3:
  + Compress changes in cache, fixing the build of large
    applications like libreoffice in some cases.
  + Add new default-branch manifest option to allow overridable
    branch name.
- Changes from version 1.0.2:
  + Print a warning when a YAML document has a float-like string
    value.
  + Handle .txz archive suffixes.
  + Set SOURCE_DATE_EPOCH to the mtime of the manifest in the
    build.
  + Update python post-processor to handle python 3.7 pyc files.
  + Allow unsetting env vars in the build options by setting them
    to null.
  + Documentation improvements.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 1.0.1:
  + Run appstream-util mirror-screenshots in the sandbox, rather
    than on the host, as the host might not have a new enough
    appstream-glib.
  + Fix build cache when a module has uncommon characters in the
    name.
* Mon Aug 27 2018 bjorn.lie@gmail.com
- Update to version 1.0.0:
  + Respect no-parallel-make with ninja.
  + Fixed regression in data: uris.
  + Warn about deprecated cmake property.
  + Make X-Flatpak-RenamedFrom a list.
  + Fix handling of mirror uris with no terminating slash.
  + Take arch into account for --skip-if-unchanged.
  + Fix --run when run inside a flatpak sandbox.
  + Ensure GIT commiter env var is set when applying git patches.
  + Keep x-* properties in the manifest when creating
    manifest.json.
  + New property paths in patch source to apply multiple patches.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 0.99.3:
  + Add X-Flatpak-RenamedFrom key to renamed desktop files.
  + Set FLATPAK_BUILDER_BUILDDIR when building module.
  + Handle large downloads better.
  + Make p2p code non-optional.
- Changes from version 0.99.2:
  + Fix --install not working due to asking for confirmation.
  + Fix builds with latest libsoup.
  + New option git-init for archives.
  + New option use-git-am for patches.
- Changes from version 0.99.1:
  + New libdir build option.
  + Support loading default options from sdk.
  + Add support for overriding c/cpp/ld/etc flags in a module.
  + Now uses libcurl to download things instead of soup, which
    means we now support ftp urls.
  + Don't prune build caches when building with
  - -{export,finish}-only.
  + rename-desktop-file now handles launchables in the appdata.
  + Archive sources support dest-filename.
  + Archive and file sources now support mirror-urls to list extra
    urls in case of network problems.
- Add pkgconfig(libcurl) BuildRequires: New dependency.
* Sun Jul  1 2018 tbechtold@suse.com
- Add "BuildRequires pkgconfig(yaml-0.1)" in flatpak-builder.spec
  to enable yaml manifest file support. This is needed to build
  flatpaks when flatpak manifest files are written in yaml (instead
  of json).
* Wed May  2 2018 bjorn.lie@gmail.com
- Update to version 0.10.10:
  + We now support yaml manifest as well as json.
  + New source type "svn" to download subversion checkouts.
  + New source type "dir" for local directories.
  + Set FLATPAK_BUILDER_N_JOBS in environment during build.
  + If not using ccache, enforce it of. This helps builds with
    meson as they pick up ccache by default, which makes no
    sense when there is no persistent storage for ccache to use.
  + New options prepend--path similar to the existing append--path
    ones, but prepending instead.
  + New argument --no-shallow-clone which disables any shallow
    clone optimizations.
  + New inherit-sdk-extensions property similar to
    inherit-extensions, but is not inherited in the platform.
  + We now ignore json keys starting with "//" and "__" allowing
    these to be used for comments.
  + Fixed a bug that caused --install to not work properly.
  + New argument --extension-tag for using the new tagged extension
    feature.
  + The build metadata now records which extensions were produced
    as part of a build.
  + New property add-build-extensions allows creating exension
    points that can be used during the build.
  + flatpak-builder --run now also binds /run/build-runtime to the
    builds, allowing it to work when building runtimes.
* Mon Mar  5 2018 fcrozat@suse.com
- Update to version 0.10.9:
  + Support -y argument, which passes it on to flatpak install, etc.
  + Fix build on glibc 2.27.
- Changes from version 0.10.8:
  + Fix build on recent glibc.
- Changes from version 0.10.7:
  + Add support for --socket=fallback-x11.
  + Fix assert in --install.
  + Fix --disable-updates for git sources.
  + When mirroring git repos, use a temporary download dir.
  + Support running flatpak-builder inside a flatpak sandbox.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Dec 20 2017 zaitor@opensuse.org
- Update to version 0.10.6:
  + New checksum types for file/archive sources: md5, sha1, sha512.
  + Support including source snippets from another file, similar to
    how module includes are supported.
  + The app id renaming in the appdata file is now more careful to
    avoid renaming other parts.
  + The cache default repo format for new caches is now
    bare-user-only which means building with flatpak-builder works
    on filesystems that don't support xattrs.
  + New --install argument will install the finished build using
    the new flatpak install install-directly-from-local-repo
    feature. This makes it easier to test local builds.
* Mon Nov 27 2017 adrien.plazas@suse.com
- Update to version 0.10.5:
  + Add support for running tests during the build (disable with
  - -disable-tests).
  + New build-option append-pkg-config to append to
    PKG_CONFIG_PATH.
  + --state-dir option lets you reuse a single directory instead of
    scattered .flatpak-builder dirs for builds, downloads and cache
    data.
  + git: Allow updates with non-fastforwarded branched.
  + Don't fail if app ships both appdata and metainfo file.
  + Support --log-system/session-bus in --run.
* Mon Nov 13 2017 jengelh@inai.de
- Adjust RPM groups.
* Tue Nov  7 2017 adrien.plazas@suse.com
- Update to version 0.10.4:
  + Fixed source bundling of git repos with older versions of git.
  + Allow git sources to use "HEAD" branch.
  + Fixed crashes in some cases of git failure.
* Thu Nov  2 2017 aplazas@suse.com
- Update to version 0.10.3:
  + Yet more fixed or older versions of git. In particular, we
    disable fsck during transfer when doing a shallow clone and the
    git version is less than 1.8.3.2.
- Changes from version 0.10.2:
  + Even more fixes for shallow git clones with older versions of
    git.
  + New property for git sources, disable-shallow-clone which falls
    back to cloning the entire remote.
- Changes from version 0.10.1:
  + Fix handling of shallow git clones with older versions of git.
  + Fix issue where flatpak-builder --run could exit if some thread
    in the parent process exited, exposeb by e.g. gnome-builder.
- Changes from version 0.10.0:
  + We now do shallow clones of git repos when downloading if
    possible.
  + The way the cache works internally was slightly tweaked which
    will cause all existing caches to be rebuilt.
- Changes from version 0.9.99:
  + Fix git source bundling on older git version.
  + New property: appdata-license lets you easily modify the
    appstream license field.
  + New source type "extra-data" which makes it easier to use
    extra-data apps.
  + We now automatically compress debuginfo unless the
    no-debuginfo-compression option is specified.
  + Appstream files called .metainfo.xml are now recognized.
  + New prepare-platform-commands property, similar
    to cleanup-platform-commands, but run before importing all the
    changes from the SDK.
  + We now apply all the deletions that happened in the SDK on the
    base when creating the platform.
- Changes from version 0.9.98:
  + build cache hits are now faster.
  + git sources have a new property "tag" which works the same as
    "branch", but improves readability when referencing a git tag.
  + flatpak-builder --run now passes --with-appdir which is useful
    when testing uninstalled builds.
  + When bundling git repos in .Sources we now make a shallow clone
    which uses a lot less space.
  + .Locale extensions now always set the new locale-subset
    property.
  + locale-subset is supported in the add-extension property.
  + build-options now also supports make-args and make-install
    args, which allows per-arch make flags.
- Bump pkgconfig(flatpak) BuildRequires to 0.10.0.
- Bump pkgconfig(ostree-1) BuildRequires to 2017.12.
* Wed Sep 13 2017 zaitor@opensuse.org
- Initial build for openSUSE, version 0.9.11.
